@@ -14,7 +14,7 @@ defmodule Makeup.Lexers.ErlangLexer do
   # Step #1: tokenize the input (into a list of tokens)
   ###################################################################
 
-  whitespace = ascii_string([?\s, ?\f, ?\n], min: 1) |> token(:whitespace)
+  whitespace = ascii_string([?\s, ?\f, ?\n, ?\t], min: 1) |> token(:whitespace)
 
   # This is the combinator that ensures that the lexer will never reject a file
   # because of invalid input syntax
@@ -212,14 +212,17 @@ defmodule Makeup.Lexers.ErlangLexer do
   # Combinators that highlight expressions surrounded by a pair of delimiters.
   punctuation =
     word_from_list(
-      [","] ++ ~w[\[ \] : _ @ \" . \#{ { } ( ) | ; => := << >> || -> \#],
+      [","] ++ ~w[\[ \] : _ @ \" . \#{ { } ( ) | ; => := << >> || -> \# &&],
       :punctuation
     )
 
   tuple = many_surrounded_by(parsec(:root_element), "{", "}")
 
   syntax_operators =
-    word_from_list(~W[+ - +? ++ = == -- * / < > /= =:= =/= =< >= ==? <- ! ? ?!], :operator)
+    word_from_list(
+      ~W[+ - +? ++ = == -- * / < > /= =:= =/= =< >= ==? <- <:- <= <:= ! ? ?!],
+      :operator
+    )
 
   record =
     token(string("#"), :operator)
@@ -409,6 +412,14 @@ defmodule Makeup.Lexers.ErlangLexer do
         [{:punctuation, %{language: :erlang}, "]"}]
       ]
     ],
+    binary: [
+      open: [
+        [{:punctuation, %{language: :erlang}, "<<"}]
+      ],
+      close: [
+        [{:punctuation, %{language: :erlang}, ">>"}]
+      ]
+    ],
     tuple: [
       open: [
         [{:punctuation, %{language: :erlang}, "{"}]
